@@ -1,3 +1,4 @@
+from .ConfigReceiver import ConfigReceiver
 from .Configurator import Configurator
 from .Filter import Filter
 from .Graph import Graph
@@ -8,6 +9,7 @@ from .Plotter import Plotter
 from .Transform import Transform
 
 __all__ = [
+    "ConfigReceiver",
     "Configurator",
     "Filter",
     "Graph",
